<?php
/**
 * Written by David Smith
 * nopeer@gmail.com
 *
 * For ATNF CSIRO
 *
 * This is the entry point for the web site. It will switch between several forms
 * - LoginForm
 * - QueryForm
 * - QueryResultsForm
 * - CartForm
 * Based on feedback from page processing.
 **/




require_once GREEN_ZONE_DIR . 'Forms/GZ_BaseForm.php';
require_once 'Forms/LoginForm.php';
require_once 'Forms/QueryForm.php';
require_once 'Forms/QueryResultsForm.php';
require_once 'Forms/CartForm.php';
require_once 'Forms/ATNFHeaderView.php';
require_once 'Forms/ATNFFooterView.php';
require_once 'Forms/ArchivePageHeader.php';
require_once 'Forms/ArchivePageFooter.php';




class ArchivePage extends GZ_BaseForm
{
  // PUBLIC
  
  function __construct( $set_gz )
  {
    global $_SESSION;
    
    parent::__construct( $set_gz );

    try
    {
      $this->login_form = new LoginForm( $set_gz );
      
      if( isset( $_SESSION['active_form'] ) && $_SESSION['active_form'] != '' )
        $this->CreateForm( $_SESSION['active_form'] );
      else
        $this->active_form = $this->login_form;
      
      $this->processing_error = null;
    }
    catch( GZ_Exception $e )
    {
      $this->processing_error = $e;
    }
  }

  function Display()
  {
    // Output the HTML header
    $html_header = new ArchivePageHeader( $this->gz );
    $html_header->Display();
    
    if( $this->processing_error == null )
    {
      try
      {
        // Draw the header with the links to other ATNF resources
        $header = new ATNFHeaderView( $this->gz );
        $header->Display();
    
        $this->active_form->Display();
        
        // Draw the footer with links to other ATNF resources
        $footer = new ATNFFooterView( $this->gz );
        $footer->Display();
      }
      catch( GZ_Exception $e )
      {
        $this->processing_error = $e;
      }
    }
    
    if( $this->processing_error != null )
    {
      echo '<br><br>';
      echo 'Caught the following exception <br>';
      echo 'Message: ' .$this->processing_error->getMessage() . '<br>';
      echo 'Method: ' . $this->processing_error->getMethod() . '<br>';
      echo 'Code: ' . $this->processing_error->getCode() . ' <br>';
      $this->gz->LogMessage( 'me', $this->processing_error->getMessage(),
                         $this->processing_error->getMethod(),
                         $this->processing_error->getCode(),
                         '' ); 
    }

    
    $html_footer = new ArchivePageFooter( $this->gz );
    $html_footer->Display();
  }
  
  private function CreateForm( $form_name )
  {
    global $_SESSION;
    
    // TODO add code to check we are asking for a valid form class.
    if( $form_name == '' )
	$this->active_form = $this->login_form;
    else
    {
      eval( '$this->active_form = new ' . $form_name . '( $this->gz );' );
      $_SESSION['active_form'] = $form_name;
    }
  }
  
  public function ReadForm()
  {
    $this->login_form->ReadForm();
    $this->active_form->ReadForm();
  }

  function ProcessActions()
  {
    try
    {
      $this->login_form->ProcessActions();
  
      if( $this->login_form->LoggedIn() )
      {
        $proc_result = 'working';
        while( $proc_result != '' )
        {
	  $proc_result = $this->active_form->ReadForm();
          $proc_result = $this->active_form->ProcessActions();
          if( $proc_result != '' )
            $this->CreateForm( $proc_result );
        }
      }
      else
      {
        $this->active_form = $this->login_form;
      }
    }
    catch( GZ_Exception $e )
    {
      $this->processing_error = $e;
    }
  }

  // PRIVATE
      
  private $processing_error;
  private $login_form;
  private $active_form;

};

?>