<?php



require_once GREEN_ZONE_DIR . 'Forms/GZ_BaseForm.php';
require_once 'Classes/General/UserData.php';
require_once 'Classes/General/DateRange.php';
require_once 'Classes/Astro/Band.php';
require_once 'Classes/Astro/MJD.php';
require_once 'Classes/Model/Observation.php';
require_once 'Classes/Model/ObsSetParameters.php';
require_once 'Classes/Queries/DateRangeQuery.php';
require_once 'Classes/Pulsar/PulsarCatalog.php';
require_once 'Classes/Queries/ObsFieldQuery.php';




class QueryForm extends GZ_BaseForm
{
  // PUBLIC

  public function __construct( $set_gz )
  {
    global $_SESSION;

    parent::__construct( $set_gz );

    $this->show_parameters = null;
    $this->parameters = null;
    
    // Default columns to show
    $this->show_parameters = Array( 'filename', 'rajd', 'decjd', 'scanlen', 'obsfreq', 'bw', 'mjd' );
    $this->LoadFromSession();
  }

  public function Display()
  {
    global $_SERVER;

    $smarty = $this->gz->CreateSmarty();

    $self = $_SERVER['PHP_SELF'];
    $self = '';
    $this->gz->smarty_assign( $smarty, 'self', $self );
    
    $this->gz->smarty_assign( $smarty, 'all_parameters', $this->all_parameters );
    $this->gz->smarty_assign( $smarty, 'show_parameters', $this->show_parameters );

    $this->gz->smarty_assign( $smarty, 'parameters', $this->parameters );
    $this->gz->smarty_assign( $smarty, 'coordinates', $this->parameters->GetCoordinates() );
    $this->gz->smarty_assign( $smarty, 'cals_window', $this->parameters->GetCalsWindow() );

    $dates_query = new DateRangeQuery();
    $full_date_range = $dates_query->Execute( $this->gz );
    
    $from_date = $this->parameters->GetDateRange()->GetFromDate();
    $to_date = $this->parameters->GetDateRange()->GetToDate();
    if( $from_date->IsUnset() )
      $from_date = $full_date_range->GetFromDate();
    if( $to_date->IsUnset() )
      $to_date = $full_date_range->GetToDate();
    
    $this->gz->smarty_assign( $smarty, 'from_date',  $from_date );
    $this->gz->smarty_assign( $smarty, 'to_date', $to_date );

    $this->gz->smarty_assign( $smarty, 'from_date_limit', $full_date_range->GetFromDate() );
    $this->gz->smarty_assign( $smarty, 'to_date_limit', $full_date_range->GetToDate() );
    
    $known_years = Array();
    for( $y = $full_date_range->GetFromDate()->GetYear(); $y < $full_date_range->GetToDate()->GetYear() + 1; $y ++ )
      $known_years[] = $y;
    $this->gz->smarty_assign( $smarty, 'known_years', $known_years );

    $this->gz->smarty_assign( $smarty, 'days_in_month', Date::$days_in_month );
    $this->gz->smarty_assign( $smarty, 'months_in_year', Date::$months_in_year );

    $this->gz->smarty_assign( $smarty, 'valid_bands', Band::$valid_bands );
    $this->gz->smarty_assign( $smarty, 'bands', $this->parameters->GetBands() );
    $this->gz->smarty_assign( $smarty, 'valid_data_types', Observation::$valid_data_types );
    
    $this->gz->smarty_assign( $smarty, 'order_dir', $this->parameters->GetOrderDirection() );
    $order_choices = Array( 'distance', 'mjd', 'obsfreq', 'filename' );
    $this->gz->smarty_assign( $smarty, 'order_choices', $order_choices );
    $this->gz->smarty_assign( $smarty, 'order_column', $this->parameters->GetOrderColumn() );

    $smarty->Display( 'QueryForm.tpl' );
  }

  public function ProcessActions()
  {
    $this->GetAllParameters();
    
    if( $this->ActionIs( 'ConeQuery' ) )
    {
      $this->parameters->ReadForm( $this->gz->_POST );
      if( $this->parameters->AreValid() )
	return 'QueryResultsForm';
    }
    return '';
  }

  // PRIVATE

  private $parameters;
  private $all_parameters;
  private $show_parameters;
  
  
  private function LoadFromSession()
  {
    global $_SESSION;
    
    if( isset( $_SESSION['show_parameters'] ) )
      $this->show_parameters = $_SESSION['show_parameters'];
    
    if( isset( $_SESSION['last_query'] ) )
      $this->parameters = $_SESSION['last_query'];
    else
      $this->parameters = new ObsSetParameters();
  }
  
  private function StoreToSession()
  {
    global $_SESSION;
    
    if( $this->show_parameters != null )
      $_SESSION['show_parameters'] = $this->show_parameters;
    
    if( $this->parameters != null )
      $_SESSION['last_query'] = $this->parameters;
  }
  
  private function GetAllParameters()
  {
    $query = new ObsFieldQuery();
    $query->SetDatabase( $this->gz );
    $query->Execute();
    $this->all_parameters = $query->GetFields();
  }
};



?>